aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.PMR/MachineStatus/MachineStatus.cs
diff options
context:
space:
mode:
authorRoy <Roy.mail.net@gmail.com>2022-07-06 21:58:07 +0300
committerRoy <Roy.mail.net@gmail.com>2022-07-06 21:58:07 +0300
commit9fa564ba8bdc768425f979eba55c95c03efea09e (patch)
treef6d47c5acdc705b61d886922e7f5463736bdb6b2 /Software/Visual_Studio/Tango.PMR/MachineStatus/MachineStatus.cs
parentcb84ea0240829179a36f6fdcce378154e6abc03e (diff)
downloadTango-9fa564ba8bdc768425f979eba55c95c03efea09e.tar.gz
Tango-9fa564ba8bdc768425f979eba55c95c03efea09e.zip
Completed auto/start ink filling change.
Diffstat (limited to 'Software/Visual_Studio/Tango.PMR/MachineStatus/MachineStatus.cs')
-rw-r--r--Software/Visual_Studio/Tango.PMR/MachineStatus/MachineStatus.cs38
1 files changed, 19 insertions, 19 deletions
diff --git a/Software/Visual_Studio/Tango.PMR/MachineStatus/MachineStatus.cs b/Software/Visual_Studio/Tango.PMR/MachineStatus/MachineStatus.cs
index ccc02e572..a50669c26 100644
--- a/Software/Visual_Studio/Tango.PMR/MachineStatus/MachineStatus.cs
+++ b/Software/Visual_Studio/Tango.PMR/MachineStatus/MachineStatus.cs
@@ -24,17 +24,17 @@ namespace Tango.PMR.MachineStatus {
string.Concat(
"ChNNYWNoaW5lU3RhdHVzLnByb3RvEhdUYW5nby5QTVIuTWFjaGluZVN0YXR1",
"cxoSTWFjaGluZVN0YXRlLnByb3RvGhJJRFNQYWNrTGV2ZWwucHJvdG8aEFNw",
- "b29sU3RhdGUucHJvdG8i+QEKDU1hY2hpbmVTdGF0dXMSNAoFU3RhdGUYASAB",
+ "b29sU3RhdGUucHJvdG8i+AEKDU1hY2hpbmVTdGF0dXMSNAoFU3RhdGUYASAB",
"KA4yJS5UYW5nby5QTVIuTWFjaGluZVN0YXR1cy5NYWNoaW5lU3RhdGUSPQoO",
"SURTUGFja3NMZXZlbHMYAiADKAsyJS5UYW5nby5QTVIuTWFjaGluZVN0YXR1",
"cy5JRFNQYWNrTGV2ZWwSGgoST3ZlcmFsbFRlbXBlcmF0dXJlGAMgASgBEjcK",
"ClNwb29sU3RhdGUYBCABKA4yIy5UYW5nby5QTVIuTWFjaGluZVN0YXR1cy5T",
- "cG9vbFN0YXRlEh4KFkF1dG9JbmtGaWxsaW5nRGlzYWJsZWQYBSABKAhCIwoh",
- "Y29tLnR3aW5lLnRhbmdvLnBtci5tYWNoaW5lc3RhdHVzYgZwcm90bzM="));
+ "cG9vbFN0YXRlEh0KFUF1dG9JbmtGaWxsaW5nRW5hYmxlZBgFIAEoCEIjCiFj",
+ "b20udHdpbmUudGFuZ28ucG1yLm1hY2hpbmVzdGF0dXNiBnByb3RvMw=="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { global::Tango.PMR.MachineStatus.MachineStateReflection.Descriptor, global::Tango.PMR.MachineStatus.IDSPackLevelReflection.Descriptor, global::Tango.PMR.MachineStatus.SpoolStateReflection.Descriptor, },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.MachineStatus.MachineStatus), global::Tango.PMR.MachineStatus.MachineStatus.Parser, new[]{ "State", "IDSPacksLevels", "OverallTemperature", "SpoolState", "AutoInkFillingDisabled" }, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.MachineStatus.MachineStatus), global::Tango.PMR.MachineStatus.MachineStatus.Parser, new[]{ "State", "IDSPacksLevels", "OverallTemperature", "SpoolState", "AutoInkFillingEnabled" }, null, null, null)
}));
}
#endregion
@@ -69,7 +69,7 @@ namespace Tango.PMR.MachineStatus {
iDSPacksLevels_ = other.iDSPacksLevels_.Clone();
overallTemperature_ = other.overallTemperature_;
spoolState_ = other.spoolState_;
- autoInkFillingDisabled_ = other.autoInkFillingDisabled_;
+ autoInkFillingEnabled_ = other.autoInkFillingEnabled_;
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -120,14 +120,14 @@ namespace Tango.PMR.MachineStatus {
}
}
- /// <summary>Field number for the "AutoInkFillingDisabled" field.</summary>
- public const int AutoInkFillingDisabledFieldNumber = 5;
- private bool autoInkFillingDisabled_;
+ /// <summary>Field number for the "AutoInkFillingEnabled" field.</summary>
+ public const int AutoInkFillingEnabledFieldNumber = 5;
+ private bool autoInkFillingEnabled_;
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public bool AutoInkFillingDisabled {
- get { return autoInkFillingDisabled_; }
+ public bool AutoInkFillingEnabled {
+ get { return autoInkFillingEnabled_; }
set {
- autoInkFillingDisabled_ = value;
+ autoInkFillingEnabled_ = value;
}
}
@@ -148,7 +148,7 @@ namespace Tango.PMR.MachineStatus {
if(!iDSPacksLevels_.Equals(other.iDSPacksLevels_)) return false;
if (OverallTemperature != other.OverallTemperature) return false;
if (SpoolState != other.SpoolState) return false;
- if (AutoInkFillingDisabled != other.AutoInkFillingDisabled) return false;
+ if (AutoInkFillingEnabled != other.AutoInkFillingEnabled) return false;
return true;
}
@@ -159,7 +159,7 @@ namespace Tango.PMR.MachineStatus {
hash ^= iDSPacksLevels_.GetHashCode();
if (OverallTemperature != 0D) hash ^= OverallTemperature.GetHashCode();
if (SpoolState != 0) hash ^= SpoolState.GetHashCode();
- if (AutoInkFillingDisabled != false) hash ^= AutoInkFillingDisabled.GetHashCode();
+ if (AutoInkFillingEnabled != false) hash ^= AutoInkFillingEnabled.GetHashCode();
return hash;
}
@@ -183,9 +183,9 @@ namespace Tango.PMR.MachineStatus {
output.WriteRawTag(32);
output.WriteEnum((int) SpoolState);
}
- if (AutoInkFillingDisabled != false) {
+ if (AutoInkFillingEnabled != false) {
output.WriteRawTag(40);
- output.WriteBool(AutoInkFillingDisabled);
+ output.WriteBool(AutoInkFillingEnabled);
}
}
@@ -202,7 +202,7 @@ namespace Tango.PMR.MachineStatus {
if (SpoolState != 0) {
size += 1 + pb::CodedOutputStream.ComputeEnumSize((int) SpoolState);
}
- if (AutoInkFillingDisabled != false) {
+ if (AutoInkFillingEnabled != false) {
size += 1 + 1;
}
return size;
@@ -223,8 +223,8 @@ namespace Tango.PMR.MachineStatus {
if (other.SpoolState != 0) {
SpoolState = other.SpoolState;
}
- if (other.AutoInkFillingDisabled != false) {
- AutoInkFillingDisabled = other.AutoInkFillingDisabled;
+ if (other.AutoInkFillingEnabled != false) {
+ AutoInkFillingEnabled = other.AutoInkFillingEnabled;
}
}
@@ -253,7 +253,7 @@ namespace Tango.PMR.MachineStatus {
break;
}
case 40: {
- AutoInkFillingDisabled = input.ReadBool();
+ AutoInkFillingEnabled = input.ReadBool();
break;
}
}